@@ -11,12 +11,12 @@ pub mod packet {
 	impl IrcPacket {
 
 		//create a new irc packet
-		fn new(from: String, to: String, cmd: String, params: String) -> IrcPacket {
+		pub fn new(from: String, to: String, cmd: String, params: String) -> IrcPacket {
 			IrcPacket { from, to, cmd, params }
 		}
 
 		//parse an irc packet to string
-		fn to_string(&self) -> String {
+		pub fn to_string(&self) -> String {
 			format!(":{from}\r\n{cmd}\r\n{to}\r\n:{params}", 
 					from=self.from,
 					cmd=self.cmd,
@@ -25,7 +25,7 @@ pub mod packet {
 		}
 
 		//parse a string to an irc packet
-		fn from_string(irc_string: String) -> IrcPacket {
+		pub fn from_string(irc_string: String) -> IrcPacket {
 			let parts_vec: Vec<&str> = irc_string.as_str().split("\r\n").collect();
 			let mut out_ircp: IrcPacket = IrcPacket { from: String::new(), to: String::new(), cmd: String::new(), params: String::new() };
 			out_ircp.from = parts_vec[0][1..].to_string();
@@ -35,7 +35,7 @@ pub mod packet {
 			return out_ircp;
 		}
 		
-		fn copy(&self) -> IrcPacket {
+		pub fn copy(&self) -> IrcPacket {
 			let from = self.from.as_str();
 			let to = self.to.as_str();
 			let cmd = self.cmd.as_str();
